@@ -1,15 +1,14 @@
 
 # -*- coding: utf-8 -*-
-import os
 from aiohttp import web
 import logging
-from unittest.mock import MagicMock, patch
 import asyncio
-import random
 import RPi.GPIO as GPIO
 from cbpi.api import *
 from . import max31865
 from subprocess import call
+import time
+from cbpi.api.dataclasses import NotificationAction, NotificationType
 
 logger = logging.getLogger(__name__)
 
@@ -23,7 +22,11 @@ logger = logging.getLogger(__name__)
     Property.Number(label="ignore_delta",configurable = True,default_value = 1, description="Ignore reading if delta between two readings is above this value. Must be positive and 0 deaxctivates filter"),
     Property.Number(label="alpha",configurable = True,default_value = 1, description="Calculate Average between 2 values. Must be between 0 and 1. 1 deactivates averaging"),
     Property.Select(label="ConfigText", options=["[0xB2] - 3 Wires Manual","[0xD2] - 3 Wires Auto","[0xA2] - 2 or 4 Wires Manual","[0xC2] - 2 or 4 Wires Auto"], description="Choose beetween 2, 3 or 4 wire PT100 & the Conversion mode at 60 Hz beetween Manual or Continuous Auto"),
-    Property.Select(label="Interval", options=[1,5,10,30,60], description="Interval in Seconds")])
+    Property.Select(label="Interval", options=[1,5,10,30,60], description="Interval in Seconds"),
+    Property.Kettle(label="Kettle", description="Reduced logging if Kettle is inactive (only Kettle or Fermenter to be selected)"),
+    Property.Fermenter(label="Fermenter", description="Reduced logging in seconds if Fermenter is inactive (only Kettle or Fermenter to be selected)"),
+    Property.Number(label="ReducedLogging", configurable=True, description="Reduced logging frequency in seconds if selected Kettle or Fermenter is inactive (default is 60 sec)")
+             ])
 
 		#
 		# Config Register
@@ -75,6 +78,22 @@ class CustomSensor(CBPiSensor):
         # counts subsequent rejected values
         self.counter = 0
 
+        self.lastlog=0
+        self.sensor=self.get_sensor(self.id)
+        self.reducedfrequency=float(self.props.get("ReducedLogging", 60))
+        
+        self.kettleid=self.props.get("Kettle", None)
+        self.fermenterid=self.props.get("Fermenter", None)
+
+        self.reducedlogging=True if self.kettleid or self.fermenterid else False
+
+        if self.kettleid is not None and self.fermenterid is not None:
+            self.reducedlogging=False
+            self.cbpi.notify("OneWire Sensor", "Sensor '" + str(self.sensor.name) + "' cant't have Fermenter and Kettle defined for reduced logging.", NotificationType.WARNING, action=[NotificationAction("OK", self.Confirm)])
+        if self.Interval >= self.reducedfrequency:
+            self.reducedlogging=False
+            self.cbpi.notify("OneWire Sensor", "Sensor '" + str(self.sensor.name) + "' has shorter or equal 'reduced logging' compared to regular interval.", NotificationType.WARNING, action=[NotificationAction("OK", self.Confirm)])
+
 
         self.max = max31865.max31865(self.csPin,self.misoPin, self.mosiPin, self.clkPin, self.ResSens, self.RefRest, int(self.ConfigReg,16))
             
@@ -89,6 +108,8 @@ class CustomSensor(CBPiSensor):
         return temp
 
     async def run(self):
+        self.kettle = self.get_kettle(self.kettleid) if self.kettleid is not None else None 
+        self.fermenter = self.get_fermenter(self.fermenterid) if self.fermenterid is not None else None
 
         while self.running == True:
             self.temp = self.read()
@@ -102,23 +123,35 @@ class CustomSensor(CBPiSensor):
                 self.counter = 0
                 self.value = round((self.temp * self.alpha + self.value_old * ( 1 - self.alpha)),2)
                 self.value_old = self.value
-                self.log_data(self.value)
                 self.push_update(self.value)
+                if self.reducedlogging:
+                    await self.logvalue()
+                else:
+                    self.log_data(self.value)
+                    self.lastlog = time.time()
             # active delta filter
             else:
                 delta = abs(self.temp-self.value_old)
                 if delta < self.delta_filter:
                     self.value = round((self.temp * self.alpha + self.value_old * ( 1 - self.alpha)),2)
-                    self.log_data(self.value)
                     self.push_update(self.value)
+                    if self.reducedlogging:
+                        await self.logvalue()
+                    else:
+                        self.log_data(self.value)
+                        self.lastlog = time.time()
                     self.value_old = self.value
                     self.counter = 0
                 else:
-                    logging.info("High Delta temp {}".format(self.temp))
+                    logging.warning("High Delta temp {}".format(self.temp))
                     if self.counter < self.max_counter:
                         self.value=self.value_old
-                        self.log_data(self.value_old)
                         self.push_update(self.value_old)
+                        if self.reducedlogging:
+                            await self.logvalue(self.value_old)
+                        else:
+                            self.log_data(self.value_old)
+                            self.lastlog = time.time()
                         self.counter +=1
                     else:
                         self.counter = 0
@@ -126,14 +159,54 @@ class CustomSensor(CBPiSensor):
                         self.value_old = self.value
                         self.log_data(self.value)
                         self.push_update(self.value)
+                        if self.reducedlogging:
+                            await self.logvalue()
+                        else:
+                            self.log_data(self.value)
+                            self.lastlog = time.time()
 
             await asyncio.sleep(self.Interval)
-    
+
+    async def logvalue(self,value=None):
+        currentvalue=self.value if value is None else value
+        now=time.time()            
+        if self.kettle is not None:
+            try:
+                kettlestatus=self.kettle.instance.state
+            except:
+                kettlestatus=False
+            if kettlestatus:
+                self.log_data(currentvalue)
+                logging.info("Kettle Active")
+                self.lastlog = time.time()
+            else:
+                logging.info("Kettle Inactive")
+                if now >= self.lastlog + self.reducedfrequency:
+                    self.log_data(currentvalue)
+                    self.lastlog = time.time()
+                    logging.info("Logged with reduced freqency")
+                    pass   
+
+        if self.fermenter is not None:
+            try:
+                fermenterstatus=self.fermenter.instance.state
+            except:
+                fermenterstatus=False
+            if fermenterstatus:
+                self.log_data(currentvalue)
+                logging.info("Fermenter Active")
+                self.lastlog = time.time()
+            else:
+                logging.info("Fermenter Inactive")
+                if now >= self.lastlog + self.reducedfrequency:
+                    self.log_data(currentvalue)
+                    self.lastlog = time.time()
+                    logging.info("Logged with reduced freqency")
+                    pass            
+
     def get_state(self):
         return dict(value=self.value)
 
-
-
 def setup(cbpi):
     cbpi.plugin.register("PT100X_Sensor", CustomSensor)
     pass
